@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /*
- *  liboaf: A library for accessing oafd in a nice way.
+ *  bonobo-activation: A library for accessing bonobo-activation-server.
  *
  *  Copyright (C) 1999, 2000 Red Hat, Inc.
  *  Copyright (C) 2000, 2001 Eazel, Inc.
@@ -31,6 +31,8 @@
 #include <bonobo-activation/bonobo-activation-i18n.h>
 #include <bonobo-activation/bonobo-activation-init.h>
 #include <bonobo-activation/bonobo-activation-private.h>
+#include <bonobo-activation/Bonobo_ActivationContext.h>
+#include <bonobo-activation/bonobo-activation-client.h>
 
 
 #ifndef _GNU_SOURCE
@@ -295,7 +297,7 @@ bonobo_activation_base_service_debug_shutdown (CORBA_Environment *ev)
 
 static void
 bonobo_activation_existing_set (const BonoboActivationBaseService *base_service, struct SysServer *ss,
-	          CORBA_Object obj, CORBA_Environment *ev)
+                                CORBA_Object obj, CORBA_Environment *ev)
 {
 	GSList *link;
 	struct SysServerInstance *ssi;
@@ -327,6 +329,11 @@ bonobo_activation_existing_set (const BonoboActivationBaseService *base_service,
 		CORBA_Object_release (ssi->already_running, ev);
 		ssi->already_running = obj;
 	}
+
+        /* FIXME: all this code is unneccesarily abstract & buggy with it */
+        if (!strcmp (base_service->name, "IDL:Bonobo/ActivationContext:1.0")) {
+                bonobo_activation_register_client (obj, ev);
+        }
 }
 
 static GSList *activator_list = NULL;
@@ -357,7 +364,7 @@ bonobo_activation_base_service_activator_add (BonoboActivationBaseServiceActivat
 
 static CORBA_Object
 bonobo_activation_activators_use (const BonoboActivationBaseService *base_service, const char **cmd,
-		    int fd_arg, CORBA_Environment *ev)
+                                  int fd_arg, CORBA_Environment *ev)
 {
 	CORBA_Object retval = CORBA_OBJECT_NIL;
 	GSList *link;
@@ -463,8 +470,8 @@ bonobo_activation_service_get (const BonoboActivationBaseService *base_service)
 
 CORBA_Object
 bonobo_activation_internal_service_get_extended (const BonoboActivationBaseService *base_service,
-                                   gboolean              existing_only,
-                                   CORBA_Environment    *ev)
+                                                 gboolean              existing_only,
+                                                 CORBA_Environment    *ev)
 {
         return bonobo_activation_service_get_internal (base_service, existing_only, ev);
 }
@@ -482,7 +489,7 @@ rloc_file_lock (const BonoboActivationBaseServiceRegistry *registry,
         int retval;
         char *err;
 
-        fn = g_strdup_printf ("/tmp/orbit-%s/oaf-register.lock", g_get_user_name ());
+        fn = g_strdup_printf ("/tmp/orbit-%s/bonobo-activation-register.lock", g_get_user_name ());
 
 	while ((lock_fd = open (fn, O_CREAT | O_RDWR, 0700)) < 0) {
 		if (errno == EEXIST) {
@@ -529,15 +536,6 @@ rloc_file_unlock (const BonoboActivationBaseServiceRegistry *registry,
                   gpointer user_data)
 {
         struct flock lock;
-#if 0
-	char *fn;
-
-
-	fn = bonobo_activation_alloca (sizeof ("/tmp/orbit-%s/oaf-register.lock") + 32);
-	sprintf (fn, "/tmp/orbit-%s/oaf-register.lock", g_get_user_name ());
-
-	unlink (fn);
-#endif
 
 	if (lock_fd >= 0) {
 
